@@ -14,6 +14,7 @@ from ..testpath import TestPath
 from ..utils.session import read_session
 from .record.session import session as session_command
 from .helper import find_or_create_session
+from ..utils.click import KeyValueType
 
 # TODO: rename files and function accordingly once the PR landscape
 
@@ -61,12 +62,12 @@ from .helper import find_or_create_session
     "--flavor",
     "flavor",
     help='flavors',
-    nargs=2,
-    type=(str, str),
+    cls=KeyValueType,
     multiple=True,
+
 )
 @click.pass_context
-def subset(context, target, session: Optional[str], base_path: Optional[str], build_name: Optional[str], rest: str, duration, flavor=[]):
+def subset(context, target, session: Optional[str], base_path: Optional[str], build_name: Optional[str], rest: str, duration, flavor):
     token, org, workspace = parse_token()
 
     session_id = find_or_create_session(context, session, build_name, flavor)
@@ -116,12 +117,10 @@ def subset(context, target, session: Optional[str], base_path: Optional[str], bu
             self._separator = s
 
         def test_path(self, path: TestPathLike):
-            if isinstance(path, str) and any(s in path for s in ('/**', '**/', '*.', "/*")):
+            if isinstance(path, str) and any(s in path for s in ('*', "?")):
                 for i in glob.iglob(path, recursive=True):
-                    if os.path.isdir(i):
-                        continue
-
-                    self.test_path(i)
+                    if os.path.isfile(i):
+                        self.test_paths.append(self.to_test_path(i))
                 return
 
             """register one test"""
