@@ -70,3 +70,15 @@ def clean_session_files(days_ago: int = 0) -> None:
             clean_date = datetime.datetime.now() - datetime.timedelta(days=days_ago)
             if file_created < clean_date:
                 child.unlink()
+
+
+def parse_session(session: str):
+    try:
+        # session format:
+        # /intake/organizations/<org name>/workspaces/<workspace name>/builds/<build name>/test_sessions/<test session id>
+        _, _, _, org, _, workspace, _, build_name, _, session_id = session.split(
+            "/")
+    except Exception as e:
+        raise Exception("Can't parse session: {}".format(session)) from e
+
+    return org, workspace, build_name, session_id
